@@ -30,6 +30,7 @@ describe 'glance::api' do
       :ignore_user_roles              => '<SERVICE DEFAULT>',
       :enabled_import_methods         => '<SERVICE DEFAULT>',
       :node_staging_uri               => '<SERVICE DEFAULT>',
+      :worker_self_reference_url      => '<SERVICE DEFAULT>',
       :image_member_quota             => '<SERVICE DEFAULT>',
       :image_cache_stall_time         => '<SERVICE DEFAULT>',
       :image_cache_max_size           => '<SERVICE DEFAULT>',
@@ -71,6 +72,7 @@ describe 'glance::api' do
         :ignore_user_roles              => 'admin',
         :enabled_import_methods         => 'glance-direct,web-download',
         :node_staging_uri               => '/tmp/staging',
+        :worker_self_reference_url      => 'http://worker1',
         :image_member_quota             => '128',
         :image_cache_stall_time         => '10',
         :image_cache_max_size           => '10737418240',
@@ -128,6 +130,7 @@ describe 'glance::api' do
             'image_cache_max_size',
             'cache_prefetcher_interval',
             'node_staging_uri',
+            'worker_self_reference_url',
             'image_member_quota',
             'limit_param_default',
             'api_limit_max',
